==> acceleratedrendering-1.0.5.1-1.21.1-alpha-fabric.1-sources.jar: com/github/argon4w/acceleratedrendering/compat/iris/mixins/vanilla/LevelRendererMixin.java <==
package com.github.argon4w.acceleratedrendering.compat.iris.mixins.vanilla;

import com.github.argon4w.acceleratedrendering.compat.iris.IrisCompatBuffers;
import com.github.argon4w.acceleratedrendering.core.CoreBuffers;
import com.github.argon4w.acceleratedrendering.core.CoreStates;
import com.github.argon4w.acceleratedrendering.core.buffers.accelerated.layers.LayerDrawType;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.minecraft.class_4184;
import net.minecraft.class_4597;
import net.minecraft.class_757;
import net.minecraft.class_761;
import net.minecraft.class_765;
import net.minecraft.class_9779;
import org.joml.Matrix4f;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(
		value		= class_761.class,
		priority	= 999
)
public class LevelRendererMixin {

	@Inject(
			method	= "renderLevel",
			at		= @At(
					value	= "INVOKE",
					target	= "Lnet/minecraft/client/renderer/MultiBufferSource$BufferSource;endBatch()V",
					ordinal = 1
			)
	)
	public void drawIrisAllCoreBuffers(
			class_9779	pDeltaTracker,
			boolean			pRenderBlockOutline,
			class_4184			pCamera,
			class_757	pGameRenderer,
			class_765	pLightTexture,
			Matrix4f		pFrustumMatrix,
			Matrix4f		pProjectionMatrix,
			CallbackInfo	ci
	) {
		CoreStates						.record			();
		CoreBuffers.ENTITY				.prepareBuffers	();
		CoreBuffers.BLOCK				.prepareBuffers	();
		CoreBuffers.POS					.prepareBuffers	();
		CoreBuffers.POS_TEX				.prepareBuffers	();
		CoreBuffers.POS_TEX_COLOR		.prepareBuffers	();
		CoreBuffers.POS_COLOR_TEX_LIGHT	.prepareBuffers	();
		CoreStates						.restore		();

		CoreBuffers.ENTITY				.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.BLOCK				.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.POS					.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.POS_TEX				.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.POS_TEX_COLOR		.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.POS_COLOR_TEX_LIGHT	.drawBuffers	(LayerDrawType.ALL);

		CoreBuffers.ENTITY				.clearBuffers	();
		CoreBuffers.BLOCK				.clearBuffers	();
		CoreBuffers.POS					.clearBuffers	();
		CoreBuffers.POS_TEX				.clearBuffers	();
		CoreBuffers.POS_TEX_COLOR		.clearBuffers	();
		CoreBuffers.POS_COLOR_TEX_LIGHT	.clearBuffers	();
	}

	@Inject(
			method	= "renderLevel",
			at		= @At(
					value	= "CONSTANT",
					args	= "stringValue=translucent",
					ordinal	= 1
			)
	)
	public void drawIrisOpaqueCoreBuffers(
			class_9779	pDeltaTracker,
			boolean			pRenderBlockOutline,
			class_4184			pCamera,
			class_757	pGameRenderer,
			class_765	pLightTexture,
			Matrix4f		pFrustumMatrix,
			Matrix4f		pProjectionMatrix,
			CallbackInfo	ci
	) {
		CoreStates						.record			();
		CoreBuffers.ENTITY				.prepareBuffers	();
		CoreBuffers.BLOCK				.prepareBuffers	();
		CoreBuffers.POS					.prepareBuffers	();
		CoreBuffers.POS_TEX				.prepareBuffers	();
		CoreBuffers.POS_TEX_COLOR		.prepareBuffers	();
		CoreBuffers.POS_COLOR_TEX_LIGHT	.prepareBuffers	();
		CoreStates						.restore		();

		CoreBuffers.ENTITY				.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.BLOCK				.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.POS					.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.POS_TEX				.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.POS_TEX_COLOR		.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.POS_COLOR_TEX_LIGHT	.drawBuffers	(LayerDrawType.OPAQUE);
	}

	@Inject(
			method	= "renderLevel",
			at		= @At(
					value	= "CONSTANT",
					args	= "stringValue=translucent",
					ordinal	= 1,
					shift	= At.Shift.AFTER
			)
	)
	public void drawIrisTranslucentCoreBuffers(
			class_9779	pDeltaTracker,
			boolean			pRenderBlockOutline,
			class_4184			pCamera,
			class_757	pGameRenderer,
			class_765	pLightTexture,
			Matrix4f		pFrustumMatrix,
			Matrix4f		pProjectionMatrix,
			CallbackInfo	ci
	) {
		CoreBuffers.ENTITY				.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.BLOCK				.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.POS					.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.POS_TEX				.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.POS_TEX_COLOR		.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.POS_COLOR_TEX_LIGHT	.drawBuffers	(LayerDrawType.TRANSLUCENT);

		CoreBuffers.ENTITY				.clearBuffers	();
		CoreBuffers.BLOCK				.clearBuffers	();
		CoreBuffers.POS					.clearBuffers	();
		CoreBuffers.POS_TEX				.clearBuffers	();
		CoreBuffers.POS_TEX_COLOR		.clearBuffers	();
		CoreBuffers.POS_COLOR_TEX_LIGHT	.clearBuffers	();
	}

	@WrapOperation(
			method	= "renderLevel",
			at		= @At(
					value	= "INVOKE",
					target	= "Lnet/minecraft/client/renderer/MultiBufferSource$BufferSource;endLastBatch()V"
			)
	)
	public void preventDrawVanillaCoreBuffers(class_4597.class_4598 instance, Operation<Void> original) {
		instance.method_37104();
	}

	@Inject(
			method	= "close",
			at		= @At("TAIL")
	)
	public void deleteIrisBuffers(CallbackInfo ci) {
		IrisCompatBuffers.BLOCK_SHADOW				.delete();
		IrisCompatBuffers.ENTITY_SHADOW				.delete();
		IrisCompatBuffers.GLYPH_SHADOW				.delete();
		IrisCompatBuffers.POS_TEX_SHADOW			.delete();
		IrisCompatBuffers.POS_TEX_COLOR_SHADOW		.delete();

		IrisCompatBuffers.ENTITY_HAND				.delete();
		IrisCompatBuffers.BLOCK_HAND				.delete();
		IrisCompatBuffers.POS_HAND					.delete();
		IrisCompatBuffers.POS_TEX_HAND				.delete();
		IrisCompatBuffers.POS_TEX_COLOR_HAND		.delete();
		IrisCompatBuffers.POS_COLOR_TEX_LIGHT_HAND	.delete();
	}
}

==> acceleratedrendering-1.0.7-1.21.1-alpha-fabric.1-sources.jar: com/github/argon4w/acceleratedrendering/compat/iris/mixins/vanilla/LevelRendererMixin.java <==
package com.github.argon4w.acceleratedrendering.compat.iris.mixins.vanilla;

import com.github.argon4w.acceleratedrendering.compat.iris.IrisCompatBuffers;
import com.github.argon4w.acceleratedrendering.core.CoreBuffers;
import com.github.argon4w.acceleratedrendering.core.CoreStates;
import com.github.argon4w.acceleratedrendering.core.buffers.accelerated.layers.LayerDrawType;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.minecraft.class_4184;
import net.minecraft.class_4597;
import net.minecraft.class_757;
import net.minecraft.class_761;
import net.minecraft.class_765;
import net.minecraft.class_9779;
import org.joml.Matrix4f;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(
		value		= class_761.class,
		priority	= 999
)
public class LevelRendererMixin {

	@Inject(
			method	= "renderLevel",
			at		= @At(
					value	= "INVOKE",
					target	= "Lnet/minecraft/client/renderer/MultiBufferSource$BufferSource;endBatch()V",
					ordinal = 1
			)
	)
	public void drawIrisAllCoreBuffers(
			class_9779	pDeltaTracker,
			boolean			pRenderBlockOutline,
			class_4184			pCamera,
			class_757	pGameRenderer,
			class_765	pLightTexture,
			Matrix4f		pFrustumMatrix,
			Matrix4f		pProjectionMatrix,
			CallbackInfo	ci
	) {
		CoreStates						.recordBuffers	();
		CoreBuffers.ENTITY				.prepareBuffers	();
		CoreBuffers.BLOCK				.prepareBuffers	();
		CoreBuffers.POS					.prepareBuffers	();
		CoreBuffers.POS_TEX				.prepareBuffers	();
		CoreBuffers.POS_TEX_COLOR		.prepareBuffers	();
		CoreBuffers.POS_COLOR_TEX_LIGHT	.prepareBuffers	();
		CoreStates						.restoreBuffers	();

		CoreBuffers.ENTITY				.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.BLOCK				.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.POS					.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.POS_TEX				.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.POS_TEX_COLOR		.drawBuffers	(LayerDrawType.ALL);
		CoreBuffers.POS_COLOR_TEX_LIGHT	.drawBuffers	(LayerDrawType.ALL);

		CoreBuffers.ENTITY				.clearBuffers	();
		CoreBuffers.BLOCK				.clearBuffers	();
		CoreBuffers.POS					.clearBuffers	();
		CoreBuffers.POS_TEX				.clearBuffers	();
		CoreBuffers.POS_TEX_COLOR		.clearBuffers	();
		CoreBuffers.POS_COLOR_TEX_LIGHT	.clearBuffers	();
	}

	@Inject(
			method	= "renderLevel",
			at		= @At(
					value	= "CONSTANT",
					args	= "stringValue=translucent",
					ordinal	= 1
			)
	)
	public void drawIrisOpaqueCoreBuffers(
			class_9779	pDeltaTracker,
			boolean			pRenderBlockOutline,
			class_4184			pCamera,
			class_757	pGameRenderer,
			class_765	pLightTexture,
			Matrix4f		pFrustumMatrix,
			Matrix4f		pProjectionMatrix,
			CallbackInfo	ci
	) {
		CoreStates						.recordBuffers	();
		CoreBuffers.ENTITY				.prepareBuffers	();
		CoreBuffers.BLOCK				.prepareBuffers	();
		CoreBuffers.POS					.prepareBuffers	();
		CoreBuffers.POS_TEX				.prepareBuffers	();
		CoreBuffers.POS_TEX_COLOR		.prepareBuffers	();
		CoreBuffers.POS_COLOR_TEX_LIGHT	.prepareBuffers	();
		CoreStates						.restoreBuffers	();

		CoreBuffers.ENTITY				.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.BLOCK				.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.POS					.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.POS_TEX				.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.POS_TEX_COLOR		.drawBuffers	(LayerDrawType.OPAQUE);
		CoreBuffers.POS_COLOR_TEX_LIGHT	.drawBuffers	(LayerDrawType.OPAQUE);
	}

	@Inject(
			method	= "renderLevel",
			at		= @At(
					value	= "CONSTANT",
					args	= "stringValue=translucent",
					ordinal	= 1,
					shift	= At.Shift.AFTER
			)
	)
	public void drawIrisTranslucentCoreBuffers(
			class_9779	pDeltaTracker,
			boolean			pRenderBlockOutline,
			class_4184			pCamera,
			class_757	pGameRenderer,
			class_765	pLightTexture,
			Matrix4f		pFrustumMatrix,
			Matrix4f		pProjectionMatrix,
			CallbackInfo	ci
	) {
		CoreBuffers.ENTITY				.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.BLOCK				.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.POS					.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.POS_TEX				.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.POS_TEX_COLOR		.drawBuffers	(LayerDrawType.TRANSLUCENT);
		CoreBuffers.POS_COLOR_TEX_LIGHT	.drawBuffers	(LayerDrawType.TRANSLUCENT);

		CoreBuffers.ENTITY				.clearBuffers	();
		CoreBuffers.BLOCK				.clearBuffers	();
		CoreBuffers.POS					.clearBuffers	();
		CoreBuffers.POS_TEX				.clearBuffers	();
		CoreBuffers.POS_TEX_COLOR		.clearBuffers	();
		CoreBuffers.POS_COLOR_TEX_LIGHT	.clearBuffers	();
	}

	@WrapOperation(
			method	= "renderLevel",
			at		= @At(
					value	= "INVOKE",
					target	= "Lnet/minecraft/client/renderer/MultiBufferSource$BufferSource;endLastBatch()V"
			)
	)
	public void preventDrawVanillaCoreBuffers(class_4597.class_4598 instance, Operation<Void> original) {
		instance.method_37104();
	}

	@Inject(
			method	= "close",
			at		= @At("TAIL")
	)
	public void deleteIrisBuffers(CallbackInfo ci) {
		IrisCompatBuffers.BLOCK_SHADOW				.delete();
		IrisCompatBuffers.ENTITY_SHADOW				.delete();
		IrisCompatBuffers.GLYPH_SHADOW				.delete();
		IrisCompatBuffers.POS_TEX_SHADOW			.delete();
		IrisCompatBuffers.POS_TEX_COLOR_SHADOW		.delete();

		IrisCompatBuffers.ENTITY_HAND				.delete();
		IrisCompatBuffers.BLOCK_HAND				.delete();
		IrisCompatBuffers.POS_HAND					.delete();
		IrisCompatBuffers.POS_TEX_HAND				.delete();
		IrisCompatBuffers.POS_TEX_COLOR_HAND		.delete();
		IrisCompatBuffers.POS_COLOR_TEX_LIGHT_HAND	.delete();
	}
}
